@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -331,11 +331,12 @@ class VideoIntelligenceServiceClient(metaclass=VideoIntelligenceServiceClientMet
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=True,
             )
 
     def annotate_video(
         self,
-        request: video_intelligence.AnnotateVideoRequest = None,
+        request: Union[video_intelligence.AnnotateVideoRequest, dict] = None,
         *,
         input_uri: str = None,
         features: Sequence[video_intelligence.Feature] = None,
@@ -350,7 +351,7 @@ class VideoIntelligenceServiceClient(metaclass=VideoIntelligenceServiceClientMet
         contains ``AnnotateVideoResponse`` (results).
 
         Args:
-            request (google.cloud.videointelligence_v1.types.AnnotateVideoRequest):
+            request (Union[google.cloud.videointelligence_v1.types.AnnotateVideoRequest, dict]):
                 The request object. Video annotation request.
             input_uri (str):
                 Input video location. Currently, only `Cloud
@@ -434,6 +435,19 @@ class VideoIntelligenceServiceClient(metaclass=VideoIntelligenceServiceClientMet
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
