@@ -133,6 +133,7 @@ class Feature(proto.Enum):
 
 class AnnotateVideoRequest(proto.Message):
     r"""Video annotation request.
+
     Attributes:
         input_uri (str):
             Input video location. Currently, only `Cloud
@@ -183,6 +184,7 @@ class AnnotateVideoRequest(proto.Message):
 
 class VideoContext(proto.Message):
     r"""Video context and/or feature-specific parameters.
+
     Attributes:
         segments (Sequence[google.cloud.videointelligence_v1p3beta1.types.VideoSegment]):
             Video segments to annotate. The segments may
@@ -236,6 +238,7 @@ class VideoContext(proto.Message):
 
 class LabelDetectionConfig(proto.Message):
     r"""Config for LABEL_DETECTION.
+
     Attributes:
         label_detection_mode (google.cloud.videointelligence_v1p3beta1.types.LabelDetectionMode):
             What labels should be detected with LABEL_DETECTION, in
@@ -277,6 +280,7 @@ class LabelDetectionConfig(proto.Message):
 
 class ShotChangeDetectionConfig(proto.Message):
     r"""Config for SHOT_CHANGE_DETECTION.
+
     Attributes:
         model (str):
             Model to use for shot change detection.
@@ -289,6 +293,7 @@ class ShotChangeDetectionConfig(proto.Message):
 
 class ObjectTrackingConfig(proto.Message):
     r"""Config for OBJECT_TRACKING.
+
     Attributes:
         model (str):
             Model to use for object tracking.
@@ -301,6 +306,7 @@ class ObjectTrackingConfig(proto.Message):
 
 class ExplicitContentDetectionConfig(proto.Message):
     r"""Config for EXPLICIT_CONTENT_DETECTION.
+
     Attributes:
         model (str):
             Model to use for explicit content detection.
@@ -313,6 +319,7 @@ class ExplicitContentDetectionConfig(proto.Message):
 
 class FaceDetectionConfig(proto.Message):
     r"""Config for FACE_DETECTION.
+
     Attributes:
         model (str):
             Model to use for face detection.
@@ -334,6 +341,7 @@ class FaceDetectionConfig(proto.Message):
 
 class PersonDetectionConfig(proto.Message):
     r"""Config for PERSON_DETECTION.
+
     Attributes:
         include_bounding_boxes (bool):
             Whether bounding boxes are included in the
@@ -355,6 +363,7 @@ class PersonDetectionConfig(proto.Message):
 
 class TextDetectionConfig(proto.Message):
     r"""Config for TEXT_DETECTION.
+
     Attributes:
         language_hints (Sequence[str]):
             Language hint can be specified if the
@@ -377,6 +386,7 @@ class TextDetectionConfig(proto.Message):
 
 class VideoSegment(proto.Message):
     r"""Video segment.
+
     Attributes:
         start_time_offset (google.protobuf.duration_pb2.Duration):
             Time-offset, relative to the beginning of the
@@ -398,6 +408,7 @@ class VideoSegment(proto.Message):
 
 class LabelSegment(proto.Message):
     r"""Video segment level annotation results for label detection.
+
     Attributes:
         segment (google.cloud.videointelligence_v1p3beta1.types.VideoSegment):
             Video segment where a label was detected.
@@ -411,6 +422,7 @@ class LabelSegment(proto.Message):
 
 class LabelFrame(proto.Message):
     r"""Video frame level annotation results for label detection.
+
     Attributes:
         time_offset (google.protobuf.duration_pb2.Duration):
             Time-offset, relative to the beginning of the
@@ -426,6 +438,7 @@ class LabelFrame(proto.Message):
 
 class Entity(proto.Message):
     r"""Detected entity from video analysis.
+
     Attributes:
         entity_id (str):
             Opaque entity ID. Some IDs may be available in `Google
@@ -444,6 +457,7 @@ class Entity(proto.Message):
 
 class LabelAnnotation(proto.Message):
     r"""Label annotation.
+
     Attributes:
         entity (google.cloud.videointelligence_v1p3beta1.types.Entity):
             Detected entity.
@@ -467,6 +481,7 @@ class LabelAnnotation(proto.Message):
 
 class ExplicitContentFrame(proto.Message):
     r"""Video frame level annotation results for explicit content.
+
     Attributes:
         time_offset (google.protobuf.duration_pb2.Duration):
             Time-offset, relative to the beginning of the
@@ -550,6 +565,7 @@ class TimestampedObject(proto.Message):
 
 class Track(proto.Message):
     r"""A track of an object instance.
+
     Attributes:
         segment (google.cloud.videointelligence_v1p3beta1.types.VideoSegment):
             Video segment of a track.
@@ -597,6 +613,7 @@ class DetectedAttribute(proto.Message):
 
 class Celebrity(proto.Message):
     r"""Celebrity definition.
+
     Attributes:
         name (str):
             The resource name of the celebrity. Have the format
@@ -630,6 +647,7 @@ class CelebrityTrack(proto.Message):
 
     class RecognizedCelebrity(proto.Message):
         r"""The recognized celebrity with confidence score.
+
         Attributes:
             celebrity (google.cloud.videointelligence_v1p3beta1.types.Celebrity):
                 The recognized celebrity.
@@ -648,6 +666,7 @@ class CelebrityTrack(proto.Message):
 
 class CelebrityRecognitionAnnotation(proto.Message):
     r"""Celebrity recognition annotation per video.
+
     Attributes:
         celebrity_tracks (Sequence[google.cloud.videointelligence_v1p3beta1.types.CelebrityTrack]):
             The tracks detected from the input video,
@@ -684,6 +703,7 @@ class DetectedLandmark(proto.Message):
 
 class FaceDetectionAnnotation(proto.Message):
     r"""Face detection annotation.
+
     Attributes:
         tracks (Sequence[google.cloud.videointelligence_v1p3beta1.types.Track]):
             The face tracks with attributes.
@@ -697,6 +717,7 @@ class FaceDetectionAnnotation(proto.Message):
 
 class PersonDetectionAnnotation(proto.Message):
     r"""Person detection annotation per video.
+
     Attributes:
         tracks (Sequence[google.cloud.videointelligence_v1p3beta1.types.Track]):
             The detected tracks of a person.
@@ -707,6 +728,7 @@ class PersonDetectionAnnotation(proto.Message):
 
 class VideoAnnotationResults(proto.Message):
     r"""Annotation results for a single video.
+
     Attributes:
         input_uri (str):
             Video file location in `Cloud
@@ -837,6 +859,7 @@ class AnnotateVideoResponse(proto.Message):
 
 class VideoAnnotationProgress(proto.Message):
     r"""Annotation progress for a single video.
+
     Attributes:
         input_uri (str):
             Video file location in `Cloud
@@ -882,6 +905,7 @@ class AnnotateVideoProgress(proto.Message):
 
 class SpeechTranscriptionConfig(proto.Message):
     r"""Config for SPEECH_TRANSCRIPTION.
+
     Attributes:
         language_code (str):
             Required. *Required* The language of the supplied audio as a
@@ -1000,6 +1024,7 @@ class SpeechTranscription(proto.Message):
 
 class SpeechRecognitionAlternative(proto.Message):
     r"""Alternative hypotheses (a.k.a. n-best list).
+
     Attributes:
         transcript (str):
             Transcript text representing the words that
@@ -1108,6 +1133,7 @@ class NormalizedBoundingPoly(proto.Message):
 
 class TextSegment(proto.Message):
     r"""Video segment level annotation results for text detection.
+
     Attributes:
         segment (google.cloud.videointelligence_v1p3beta1.types.VideoSegment):
             Video segment where a text snippet was
@@ -1183,6 +1209,7 @@ class ObjectTrackingFrame(proto.Message):
 
 class ObjectTrackingAnnotation(proto.Message):
     r"""Annotations corresponding to one tracked object.
+
     Attributes:
         segment (google.cloud.videointelligence_v1p3beta1.types.VideoSegment):
             Non-streaming batch mode ONLY.
@@ -1410,11 +1437,13 @@ class StreamingVideoAnnotationResults(proto.Message):
 
 
 class StreamingShotChangeDetectionConfig(proto.Message):
-    r"""Config for STREAMING_SHOT_CHANGE_DETECTION.    """
+    r"""Config for STREAMING_SHOT_CHANGE_DETECTION.
+    """
 
 
 class StreamingLabelDetectionConfig(proto.Message):
     r"""Config for STREAMING_LABEL_DETECTION.
+
     Attributes:
         stationary_camera (bool):
             Whether the video has been captured from a
@@ -1427,15 +1456,18 @@ class StreamingLabelDetectionConfig(proto.Message):
 
 
 class StreamingExplicitContentDetectionConfig(proto.Message):
-    r"""Config for STREAMING_EXPLICIT_CONTENT_DETECTION.    """
+    r"""Config for STREAMING_EXPLICIT_CONTENT_DETECTION.
+    """
 
 
 class StreamingObjectTrackingConfig(proto.Message):
-    r"""Config for STREAMING_OBJECT_TRACKING.    """
+    r"""Config for STREAMING_OBJECT_TRACKING.
+    """
 
 
 class StreamingAutomlActionRecognitionConfig(proto.Message):
     r"""Config for STREAMING_AUTOML_ACTION_RECOGNITION.
+
     Attributes:
         model_name (str):
             Resource name of AutoML model. Format:
@@ -1447,6 +1479,7 @@ class StreamingAutomlActionRecognitionConfig(proto.Message):
 
 class StreamingAutomlClassificationConfig(proto.Message):
     r"""Config for STREAMING_AUTOML_CLASSIFICATION.
+
     Attributes:
         model_name (str):
             Resource name of AutoML model. Format:
@@ -1458,6 +1491,7 @@ class StreamingAutomlClassificationConfig(proto.Message):
 
 class StreamingAutomlObjectTrackingConfig(proto.Message):
     r"""Config for STREAMING_AUTOML_OBJECT_TRACKING.
+
     Attributes:
         model_name (str):
             Resource name of AutoML model. Format:
@@ -1469,6 +1503,7 @@ class StreamingAutomlObjectTrackingConfig(proto.Message):
 
 class StreamingStorageConfig(proto.Message):
     r"""Config for streaming storage option.
+
     Attributes:
         enable_storage_annotation_result (bool):
             Enable streaming storage. Default: false.
